/*
 * Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
 * Departamento de Informatica - Universidade Federal do Parana
 *
 * This file is part of blendb.
 *
 * blend is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * blendb is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with blendb.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * Parameters used to create a Tag object.
 * Parameters used to define tag object in the configuration file.
 * Also the string description of a tag.
 */
export interface TagOptions {
    /**  Tag name. */
    name: string;
    /** Breif description of what this tag represents. */
    description?: string;
}

/**
 * A Tag can be attached to other elements (such as metrics and dimensions)
 * to create groups of similar elements. A tag can also be used to filter
 * these elements, search for itens that only contain the given tags.
 */
export class Tag {
    /**  Tag name. */
    public readonly name: string;
    /** Breif description of what this tag represents. */
    public readonly description: string;

    /**
     * Creates a tag.
     * @param options - Parameters required to create a tag.
     */
    constructor(options: TagOptions) {
        this.name = options.name;
        this.description = (options.description) ? options.description : "";
    }

    /**
     * Creates a object with the same options used to create this
     * tag as strings. Used to inform the API users.
     */
    public strOptions(): TagOptions {
        return {
            name: this.name
            , description: this.description
        };
    }
}
